/* ***********************IMPORTANT *********************************************
 *  Copyright (C) 2004-2007 Thierry Lagarde <tlagarde@users.sourceforge.net>
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License.
 *
 *
 *                      ********************
 *
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *
 *                      ********************
 *
 *
 * You are highly encouraged to send your changes to <tlagarde@users.sourceforge.net>
 * for possible incorporation into the main distribution.
 * By sending these changes to <tlagarde@users.sourceforge.net>,
 * it is assumed that you are offering <tlagarde@users.sourceforge.net>
 * the unlimited, non-exclusive right to reuse, modify, and relicense the code.
 *
 *
 *                      ********************
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 **************************************************************************************/
#ifndef         __GCONF
#define         __GCONF

#include <gconf/gconf-client.h>
GConfClient *client_gconf;


enum enum_Gconf {
	BOOL_FIRST_START =0, 
	INT_DEBUG, 
	BOOL_START_MINIMIZED,
	BOOL_MINIMIZED_TRAY_ICON, 
	BOOL_LOAD_DEFAULT_NETWORK, 
	CHAR_LOAD_DEFAULT_NETWORK_FILE, 
	BOOL_AUTO_SAVE_NETWORK, 
	CHAR_AUTO_SAVE_NETWORK_FILE, 
	CHAR_SERVEUR_SMTP,
	INT_AUDIO_DEVICE,
	INT_VERSION_SIGNATURE,
	CHAR_CHEMIN_SON_ALERT,
	INT_ROOT_POSITION_X,
	INT_ROOT_POSITION_Y, 
	INT_ROOT_SIZE_X, 
	INT_ROOT_SIZE_Y,
	INT_SETTINGS_SIZE_X, 
	INT_SETTINGS_SIZE_Y,	
	INT_ICONLIST_ICON_WIDTH,
	INT_V_PANED_POSITION, 
	INT_H_PANED_POSITION,
	BOOL_TREE_VIEW_SET_HOVER_EXPAND,
	BOOL_TREE_VIEW_SET_RULES_HINT,
	INT_THREAD_MAX,
	BOOL_NORMAL_MODE,
	BOOL_IP_DYNAMIC,
	CHAR_WIZARD_NAME_NETWORK,
	CHAR_WIZARD_ICON_NETWORK,
	INT_WIZARD_SELECT_NETWORK,
	CHAR_WIZARD_RESTORE_FOLDER,
	CHAR_WIZARD_CONNECT_IP_ADDRESS, 
	INT_WIZARD_CONNECT_PORT,
	CHAR_WIZARD_CONNECT_USER,
	CHAR_WIZARD_CONNECT_PASSWORD,
	CHAR_EXTENSION_SXC,
	CHAR_EXTENSION_SXD,
	CHAR_EXTENSION_SXI,
	CHAR_EXTENSION_SXW,
	CHAR_EXTENSION_PNG,
	CHAR_EXTENSION_JPG,
	CHAR_EXTENSION_XPM,
	CHAR_EXTENSION_RPM,
	CHAR_EXTENSION_DEB,
	CHAR_EXTENSION_MP3,
	CHAR_EXTENSION_OGG,
	CHAR_EXTENSION_WAV,
	CHAR_EXTENSION_HTML,
	CHAR_EXTENSION_PDF,
	CHAR_EXTENSION_README,
	CHAR_EXTENSION_CONF,
	CHAR_EXTENSION_C,
	CHAR_EXTENSION_H,
	CHAR_EXTENSION_TAR,
	CHAR_EXTENSION_BZ2,
	CHAR_EXTENSION_GZ,
	CHAR_EXTENSION_TXT,
	CHAR_EXTENSION_AVI,
	CHAR_EXTENSION_DOC,
	CHAR_EXTENSION_OGM	
};

gboolean gconf_error(GError **err);

char *Lecture_Gconf_Char (int i);
gboolean Lecture_Gconf_Boolean (int i);
int Lecture_Gconf_Int (int i);
void Enregistrement_Gconf_Char (int i, char *valeur);
void Enregistrement_Gconf_Boolean (int i, gboolean valeur);
void Enregistrement_Gconf_Entier (int i, int valeur);

int Lecture_Info_Conf_Int (char *path);
gboolean Lecture_Info_Conf_Bool (char *path);
char * Lecture_Info_Conf_Char (char *path);
void Enregistrement_Info_Conf_Char (gchar *path, gchar *Donnee);
void Enregistrement_Info_Conf_Bool (char *path, gboolean Donnee);
void Enregistrement_Info_Conf_Int (char *path, int Donnee);
#endif
